summaryrefslogtreecommitdiff
path: root/gcc/varpool.c
diff options
context:
space:
mode:
authorJakub Jelinek <jakub@redhat.com>2019-11-09 00:56:37 +0100
committerJakub Jelinek <jakub@gcc.gnu.org>2019-11-09 00:56:37 +0100
commitdfea3d6fde2b62e76d06c5ab78db7931b5f4ba13 (patch)
treeeb9d1a51051c51c7112160cd56f63b6a1956fe03 /gcc/varpool.c
parenta63d6356bebcf96c8931cad1dae50ce553db0df3 (diff)
symtab.c: Fix comment typos.
* symtab.c: Fix comment typos. * cgraphunit.c: Likewise. * cgraph.h: Likewise. * cgraphclones.c: Likewise. * cgraph.c: Likewise. * varpool.c: Likewise. * tree-ssa-strlen.c: Likewise. * ipa-sra.c: Likewise. (scan_expr_access, check_all_callers_for_issues): Fix typo in a dump message. From-SVN: r277995
Diffstat (limited to 'gcc/varpool.c')
-rw-r--r--gcc/varpool.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/gcc/varpool.c b/gcc/varpool.c
index d4b83429c12..ff49ad9f517 100644
--- a/gcc/varpool.c
+++ b/gcc/varpool.c
@@ -204,7 +204,7 @@ varpool_node::remove_initializer (void)
&& debug_info_level == DINFO_LEVEL_NONE
/* When doing declaration merging we have duplicate
entries for given decl. Do not attempt to remove
- the boides, or we will end up remiving
+ the bodies, or we will end up removing
wrong one. */
&& symtab->state != LTO_STREAMING)
DECL_INITIAL (decl) = error_mark_node;
@@ -365,7 +365,7 @@ varpool_node::ctor_useable_for_folding_p (void)
overridden at link or run time.
It is actually requirement for C++ compiler to optimize const variables
- consistently. As a GNU extension, do not enfore this rule for user defined
+ consistently. As a GNU extension, do not enforce this rule for user defined
weak variables, so we support interposition on:
static const int dummy = 0;
extern const int foo __attribute__((__weak__, __alias__("dummy")));
@@ -409,7 +409,7 @@ ctor_for_folding (tree decl)
return error_mark_node;
/* Do not care about automatic variables. Those are never initialized
- anyway, because gimplifier exapnds the code. */
+ anyway, because gimplifier expands the code. */
if (!TREE_STATIC (decl) && !DECL_EXTERNAL (decl))
{
gcc_assert (!TREE_PUBLIC (decl));
@@ -552,7 +552,7 @@ varpool_node::assemble_aliases (void)
bool
varpool_node::assemble_decl (void)
{
- /* Aliases are outout when their target is produced or by
+ /* Aliases are output when their target is produced or by
output_weakrefs. */
if (alias)
return false;
@@ -790,8 +790,8 @@ varpool_node::create_extra_name_alias (tree alias, tree decl)
alias_node = varpool_node::create_alias (alias, decl);
alias_node->cpp_implicit_alias = true;
- /* Extra name alias mechanizm creates aliases really late
- via DECL_ASSEMBLER_NAME mechanizm.
+ /* Extra name alias mechanism creates aliases really late
+ via DECL_ASSEMBLER_NAME mechanism.
This is unfortunate because they are not going through the
standard channels. Ensure they get output. */
if (symtab->cpp_implicit_aliases_done)